Class: Telegrammer::DataTypes::InlineQueryResultArticle

Inherits:
Base
  • Object
show all
Defined in:
lib/telegrammer/data_types/inline_query_result_article.rb

Overview

Telegram InlineQueryResultArticle data type

See more at core.telegram.org/bots/api#inlinequeryresultarticle

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

Optional. Short description of the result



19
20
21
# File 'lib/telegrammer/data_types/inline_query_result_article.rb', line 19

def description
  @description
end

#disable_web_page_previewBoolean

Optional. Disables link previews for links in the sent message



19
20
21
# File 'lib/telegrammer/data_types/inline_query_result_article.rb', line 19

def disable_web_page_preview
  @disable_web_page_preview
end

#hide_urlBoolean

Optional. Pass True, if you don’t want the URL to be shown in the message



19
20
21
# File 'lib/telegrammer/data_types/inline_query_result_article.rb', line 19

def hide_url
  @hide_url
end

#idString

Unique identifier for this result, 1-64 Bytes



19
20
21
# File 'lib/telegrammer/data_types/inline_query_result_article.rb', line 19

def id
  @id
end

#message_textString

Text of the message to be sent



19
20
21
# File 'lib/telegrammer/data_types/inline_query_result_article.rb', line 19

def message_text
  @message_text
end

#parse_modeString

Optional. Send “Markdown”, if you want Telegram apps to show bold, italic and inline URLs in your bot’s message.



19
20
21
# File 'lib/telegrammer/data_types/inline_query_result_article.rb', line 19

def parse_mode
  @parse_mode
end

#thumb_heightInteger

Optional. Thumbnail height



19
20
21
# File 'lib/telegrammer/data_types/inline_query_result_article.rb', line 19

def thumb_height
  @thumb_height
end

#thumb_urlString

Optional. Url of the thumbnail for the result



19
20
21
# File 'lib/telegrammer/data_types/inline_query_result_article.rb', line 19

def thumb_url
  @thumb_url
end

#thumb_widthInteger

Optional. Thumbnail width



19
20
21
# File 'lib/telegrammer/data_types/inline_query_result_article.rb', line 19

def thumb_width
  @thumb_width
end

#titleString

Title of the result



19
20
21
# File 'lib/telegrammer/data_types/inline_query_result_article.rb', line 19

def title
  @title
end

#typeString

Type of the result, must be article



19
20
21
# File 'lib/telegrammer/data_types/inline_query_result_article.rb', line 19

def type
  @type
end

#urlString

Optional. URL of the result



19
20
21
# File 'lib/telegrammer/data_types/inline_query_result_article.rb', line 19

def url
  @url
end